@@ -97,3 +97,14 @@ void Fir1::zeroCoeff() {
 	memset(coefficients, 0, sizeof(double)*taps);
 	offset = 0;
 }
+
+void Fir1::getCoeff(double* coeff_data, unsigned number_of_taps) const {
+	
+	if (number_of_taps < taps)
+		throw std::out_of_range("Fir1: target of getCoeff: too many weights to copy into target");
+ 
+	memcpy(coeff_data, coefficients, taps * sizeof(double));
+	if (number_of_taps > taps)
+		memset(&coeff_data[taps], 0, (number_of_taps - taps)*sizeof(double));
+}
+
